import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.cloud_assembly_schema._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/cx-api", "1.85.0", __name__[0:-6], "cx-api@1.85.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
